@@ -1,10 +1,13 @@
 import os
 
+import click
 import confuse
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "1.1.0"
+__version__ = "1.2.1"
+
+from hookee.exception import HookeeConfigError
 
 template = {
     "port": int,
@@ -31,25 +34,57 @@ class Config:
     values from the command line, this is where updated values are stored) which in turn can be overridden by
     passing args to the CLI.
 
-    :var ctx: The ``click`` context.
-    :vartype ctx: click.Context
+    If instantiating for a custom integration, args that would otherwise have been passed to and validated by the CLI
+    (see ``hookee --help``) can instead be passed as ``kwargs`` here to ensure the same validation is done.
+    For example:
+
+    .. code-block:: python
+
+        from hookee.conf import Config
+
+        config = Config(subdomain="my_domain",
+                        region="eu")
+
+    A callback function can also be passed instead of ``response`` and ``content-type`` (or needing to use
+    plugins) when integrating with ``hookee``'s APIs:
+
+    .. code-block:: python
+
+        from hookee.conf import Config
+
+        def response_callback(request, response):
+            response.data = "<Response>Ok</Response>"
+            response.headers["Content-Type"] = "application/xml"
+            return response
+
+        config = Config(response_callback=response_callback)
+
     :var config_obj: The templated config object.
     :vartype config_obj: confuse.core.Configuration
     :var config_dir: The directory of the config being used.
     :vartype config_dir: str
-    :var config_filename: The full path to the config file being used.
-    :vartype config_filename: str
+    :var config_path: The full path to the config file being used.
+    :vartype config_path: str
     :var config_data: The parsed and validated config data. Use :func:`get`, :func:`set`, and other accessors
         to interact with the data.
     :vartype config_data: confuse.templates.AttrDict
+    :var click_logging: ``True`` if ``click`` should be used for log output, which enables colors and formatting when
+        logging to a console, ``False`` if a logger should be used. If not passed, ``True`` if a :class:`click.Context`
+        is found to be active. Not persisted to the config file.
+    :vartype click_logging: bool
+    :var response_callback: The response callback function, if defined. Not persisted to the config file.
+    :vartype response_callback: types.FunctionType, optional
     """
 
-    def __init__(self, ctx):
-        self.ctx = ctx
-
+    def __init__(self, click_logging=None, **kwargs):
         try:
+            if click_logging is None:
+                click_logging = click.get_current_context(silent=True) is not None
+
+            self.response_callback = kwargs.pop("response_callback", None)
+
             config = confuse.Configuration("hookee", __name__)
-            config.set_args(ctx.obj)
+            config.set_args(kwargs)
 
             self.config_obj = config
             self.config_dir = self.config_obj.config_dir()
@@ -57,17 +92,24 @@ class Config:
 
             self.config_data = config.get(template)
 
+            self.click_logging = click_logging
+
+            if self.config_data.get("response") and self.response_callback:
+                raise HookeeConfigError("Can't define both \"response\" and \"response_callback\".")
+            elif self.response_callback and not callable(self.response_callback):
+                raise HookeeConfigError("\"response_callback\" must be a function.")
+
             plugins_dir = os.path.expanduser(self.config_data["plugins_dir"])
             if not os.path.exists(plugins_dir):
                 os.makedirs(plugins_dir)
         except confuse.NotFoundError as e:
-            ctx.fail("The config file is invalid: {}.".format(str(e)))
+            raise HookeeConfigError("The config file is invalid: {}.".format(str(e)))
         except (confuse.ConfigReadError, ValueError):
-            ctx.fail("The config file is not valid YAML.")
+            raise HookeeConfigError("The config file is not valid YAML.")
 
     def get(self, key):
         """
-        Get the config value for the given key.
+        Get the config value for the given key of persisted data.
 
         :param key: The key.
         :type key: str
@@ -126,25 +168,6 @@ class Config:
         self._write_config_objects_to_file()
 
     def _write_config_objects_to_file(self):
+        # TODO: confuse's dump() should actually take care of this, we just need to set a source as `default`
         with open(self.config_path, "w") as f:
             f.write(self.config_obj.dump())
-
-
-class Context:
-    """
-    The ``HookeeManager`` class can be invoked programmatically, avoiding the CLI, and this object can be passed for
-    the ``ctx`` (which otherwise comes from the CLI). Populate the ``obj`` dictionary with keys/values that would
-    otherwise be passed as args to the CLI for proper initialization.
-
-    :var obj: A dictionary of keys/values matching valid CLI args.
-    :vartype obj: dict, optional
-    """
-
-    def __init__(self, obj=None):
-        if obj is None:
-            obj = {}
-
-        self.obj = obj
-
-
-default_context = Context()
