@@ -1,6 +1,6 @@
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "1.0.1"
+__version__ = "1.2.0"
 
 
 class HookeeError(Exception):
@@ -10,6 +10,13 @@ class HookeeError(Exception):
     pass
 
 
+class HookeeConfigError(HookeeError):
+    """
+    Raised when there is an error initializing ``hookee` configuration.
+    """
+    pass
+
+
 class HookeePluginValidationError(HookeeError):
     """
     Raised when a module fails to validate as a valid ``hookee`` plugin.
