@@ -1,5 +1,6 @@
 import inspect
 import json
+import logging
 import os
 import sys
 import xml.dom.minidom
@@ -8,12 +9,28 @@ import click
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "1.1.0"
+__version__ = "1.2.1"
+
+logger = logging.getLogger(__name__)
 
 
 class PrintUtil:
     """
-    An object that provides helpful methods for printing to the console through ``click`` and the CLI.
+    An object that provides helper methods for logging output. If :class:`~hookee.conf.Config`'s ``click_logging`` is
+    ``True`` (which will happen by default if a :class:`click.Context` is found to be active), this logging will be
+    done through ``click``, otherwise the ``hookee`` logger will be used.
+
+    If ``click_logging`` is disabled, output sent through this utility can still be interacted with by ensuring the a
+    logger is setup. For example, this would add a handler to the ``hookee`` logger that just logs output back to
+    the console:
+
+    .. code-block:: python
+
+        import logging
+
+        logger = logging.getLogger("hookee")
+        logger.setLevel(logging.INFO)
+        logging.getLogger().addHandler(logging.StreamHandler())
 
     :var config: The ``hookee`` configuration.
     :vartype config: Config
@@ -27,11 +44,11 @@ class PrintUtil:
         return self.config.get("console_width")
 
     def print_config_update(self, msg):
-        click.secho("\n--> {}\n".format(msg), fg="green")
+        self.print_basic("\n--> {}\n".format(msg), fg="green")
 
     def print_open_header(self, title, delimiter="-", fg="green"):
         """
-        Print an opening header to the CLI.
+        Log an opening header with a title and a new line before and after.
 
         :param title: The header title.
         :type title: str
@@ -42,28 +59,28 @@ class PrintUtil:
         """
         width = int((self.console_width - len(title)) / 2)
 
-        click.echo("")
-        click.secho("{}{}{}".format(delimiter * width, title, delimiter * width), fg=fg, bold=True)
-        click.echo("")
+        self.print_basic()
+        self.print_basic("{}{}{}".format(delimiter * width, title, delimiter * width), fg=fg, bold=True)
+        self.print_basic()
 
     def print_close_header(self, delimiter="-", fg="green", blank_line=True):
         """
-        Print a closing header to the CLI.
+        Log a closing header with an optional new line before.
 
         :param delimiter: The title of the XML blob.
         :type delimiter: str
         :param fg: The color to make the text.
         :type fg: str, optional
-        :param blank_line: ``True`` if a blank line should preceed the closing header.
+        :param blank_line: ``True`` if a blank line should precede the closing header.
         :type blank_line: bool
         """
         if blank_line:
-            click.echo("")
-        click.secho(delimiter * self.console_width, fg=fg, bold=True)
+            self.print_basic()
+        self.print_basic(delimiter * self.console_width, fg=fg, bold=True)
 
     def print_dict(self, title, data, fg="green"):
         """
-        Print formatted dictionary data to the CLI.
+        Log formatted dictionary data.
 
         :param title: The title of the XML blob.
         :type title: str
@@ -72,11 +89,11 @@ class PrintUtil:
         :param fg: The color to make the text.
         :type fg: str, optional
         """
-        click.secho("{}: {}".format(title, json.dumps(data, indent=4)), fg=fg)
+        self.print_basic("{}: {}".format(title, json.dumps(data, indent=4)), fg=fg)
 
     def print_xml(self, title, data, fg="green"):
         """
-        Print formatted XML to the CLI.
+        Log formatted XML.
 
         :param title: The title of the XML blob.
         :type title: str
@@ -85,20 +102,29 @@ class PrintUtil:
         :param fg: The color to make the text.
         :type fg: str, optional
         """
-        click.secho("{}: {}".format(title, xml.dom.minidom.parseString(data).toprettyxml()), fg=fg)
+        self.print_basic("{}: {}".format(title, xml.dom.minidom.parseString(data).toprettyxml()), fg=fg)
 
-    def print_basic(self, data="", fg="white", bold=False):
+    def print_basic(self, msg="", fg="white", bold=False, print_when_logging=False):
         """
-        Print a status update in a boot sequence.
+        Log a basic message. The message will be logged via ``click``, if ``click_logging`` is enabled in
+        :class:`~hookee.conf.Config`, or appended to the logger.
 
-        :param data: The update to print.
-        :type data: str, optional
+        :param msg: The update to print.
+        :type msg: str, optional
         :param fg: The color to make the text.
         :type fg: str, optional
-        :param bold: True if the output should be bold.
+        :param bold: ``True`` if the output should be bold.
         :type bold: bool, optional
+        :param print_when_logging: ``True`` if, when ``click_logging`` is ``False``, ``msg`` should print to the
+            console instead of appending to the logger.
+        :type print_when_logging: bool, optional
         """
-        click.secho(data, fg=fg, bold=bold)
+        if self.config.click_logging:
+            click.secho(msg, fg=fg, bold=bold)
+        elif not print_when_logging:
+            logger.info(msg)
+        else:
+            print(msg)
 
 
 def python3_gte():
